from ai.stigmer.commons.apiresource import io_pb2 as _io_pb2
from ai.stigmer.commons.apiresource import rpc_service_options_pb2 as _rpc_service_options_pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as _method_options_pb2
from ai.stigmer.tenancy.project.v1 import api_pb2 as _api_pb2
from ai.stigmer.tenancy.project.v1 import io_pb2 as _io_pb2_1
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UsageMetrics(_message.Message):
    __slots__ = ("prompt_tokens", "completion_tokens", "total_tokens", "llm_call_count", "primary_model", "cache_creation_tokens", "cache_read_tokens", "model_breakdown", "estimated_cost_usd", "tool_result_chars_truncated", "llm_calls", "total_duration_ms", "llm_duration_ms", "tool_duration_ms", "approval_wait_duration_ms", "primary_provider")
    PROMPT_TOKENS_FIELD_NUMBER: _ClassVar[int]
    COMPLETION_TOKENS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_TOKENS_FIELD_NUMBER: _ClassVar[int]
    LLM_CALL_COUNT_FIELD_NUMBER: _ClassVar[int]
    PRIMARY_MODEL_FIELD_NUMBER: _ClassVar[int]
    CACHE_CREATION_TOKENS_FIELD_NUMBER: _ClassVar[int]
    CACHE_READ_TOKENS_FIELD_NUMBER: _ClassVar[int]
    MODEL_BREAKDOWN_FIELD_NUMBER: _ClassVar[int]
    ESTIMATED_COST_USD_FIELD_NUMBER: _ClassVar[int]
    TOOL_RESULT_CHARS_TRUNCATED_FIELD_NUMBER: _ClassVar[int]
    LLM_CALLS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_DURATION_MS_FIELD_NUMBER: _ClassVar[int]
    LLM_DURATION_MS_FIELD_NUMBER: _ClassVar[int]
    TOOL_DURATION_MS_FIELD_NUMBER: _ClassVar[int]
    APPROVAL_WAIT_DURATION_MS_FIELD_NUMBER: _ClassVar[int]
    PRIMARY_PROVIDER_FIELD_NUMBER: _ClassVar[int]
    prompt_tokens: int
    completion_tokens: int
    total_tokens: int
    llm_call_count: int
    primary_model: str
    cache_creation_tokens: int
    cache_read_tokens: int
    model_breakdown: _containers.RepeatedCompositeFieldContainer[ModelUsage]
    estimated_cost_usd: float
    tool_result_chars_truncated: int
    llm_calls: _containers.RepeatedCompositeFieldContainer[LlmCallMetrics]
    total_duration_ms: int
    llm_duration_ms: int
    tool_duration_ms: int
    approval_wait_duration_ms: int
    primary_provider: str
    def __init__(self, prompt_tokens: _Optional[int] = ..., completion_tokens: _Optional[int] = ..., total_tokens: _Optional[int] = ..., llm_call_count: _Optional[int] = ..., primary_model: _Optional[str] = ..., cache_creation_tokens: _Optional[int] = ..., cache_read_tokens: _Optional[int] = ..., model_breakdown: _Optional[_Iterable[_Union[ModelUsage, _Mapping]]] = ..., estimated_cost_usd: _Optional[float] = ..., tool_result_chars_truncated: _Optional[int] = ..., llm_calls: _Optional[_Iterable[_Union[LlmCallMetrics, _Mapping]]] = ..., total_duration_ms: _Optional[int] = ..., llm_duration_ms: _Optional[int] = ..., tool_duration_ms: _Optional[int] = ..., approval_wait_duration_ms: _Optional[int] = ..., primary_provider: _Optional[str] = ...) -> None: ...

class ModelUsage(_message.Message):
    __slots__ = ("model", "provider", "input_tokens", "output_tokens", "cache_creation_tokens", "cache_read_tokens", "call_count", "input_price_per_million", "output_price_per_million", "cache_creation_price_per_million", "cache_read_price_per_million", "estimated_cost_usd")
    MODEL_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    INPUT_TOKENS_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_TOKENS_FIELD_NUMBER: _ClassVar[int]
    CACHE_CREATION_TOKENS_FIELD_NUMBER: _ClassVar[int]
    CACHE_READ_TOKENS_FIELD_NUMBER: _ClassVar[int]
    CALL_COUNT_FIELD_NUMBER: _ClassVar[int]
    INPUT_PRICE_PER_MILLION_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_PRICE_PER_MILLION_FIELD_NUMBER: _ClassVar[int]
    CACHE_CREATION_PRICE_PER_MILLION_FIELD_NUMBER: _ClassVar[int]
    CACHE_READ_PRICE_PER_MILLION_FIELD_NUMBER: _ClassVar[int]
    ESTIMATED_COST_USD_FIELD_NUMBER: _ClassVar[int]
    model: str
    provider: str
    input_tokens: int
    output_tokens: int
    cache_creation_tokens: int
    cache_read_tokens: int
    call_count: int
    input_price_per_million: float
    output_price_per_million: float
    cache_creation_price_per_million: float
    cache_read_price_per_million: float
    estimated_cost_usd: float
    def __init__(self, model: _Optional[str] = ..., provider: _Optional[str] = ..., input_tokens: _Optional[int] = ..., output_tokens: _Optional[int] = ..., cache_creation_tokens: _Optional[int] = ..., cache_read_tokens: _Optional[int] = ..., call_count: _Optional[int] = ..., input_price_per_million: _Optional[float] = ..., output_price_per_million: _Optional[float] = ..., cache_creation_price_per_million: _Optional[float] = ..., cache_read_price_per_million: _Optional[float] = ..., estimated_cost_usd: _Optional[float] = ...) -> None: ...

class LlmCallMetrics(_message.Message):
    __slots__ = ("sequence", "model", "provider", "input_tokens", "output_tokens", "cache_creation_tokens", "cache_read_tokens", "estimated_cost_usd", "duration_ms", "timestamp")
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    MODEL_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    INPUT_TOKENS_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_TOKENS_FIELD_NUMBER: _ClassVar[int]
    CACHE_CREATION_TOKENS_FIELD_NUMBER: _ClassVar[int]
    CACHE_READ_TOKENS_FIELD_NUMBER: _ClassVar[int]
    ESTIMATED_COST_USD_FIELD_NUMBER: _ClassVar[int]
    DURATION_MS_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    sequence: int
    model: str
    provider: str
    input_tokens: int
    output_tokens: int
    cache_creation_tokens: int
    cache_read_tokens: int
    estimated_cost_usd: float
    duration_ms: int
    timestamp: str
    def __init__(self, sequence: _Optional[int] = ..., model: _Optional[str] = ..., provider: _Optional[str] = ..., input_tokens: _Optional[int] = ..., output_tokens: _Optional[int] = ..., cache_creation_tokens: _Optional[int] = ..., cache_read_tokens: _Optional[int] = ..., estimated_cost_usd: _Optional[float] = ..., duration_ms: _Optional[int] = ..., timestamp: _Optional[str] = ...) -> None: ...



from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ExecutionContextSpec(_message.Message):
    __slots__ = ("execution_id", "data")
    class DataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: ExecutionValue
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[ExecutionValue, _Mapping]] = ...) -> None: ...
    EXECUTION_ID_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    execution_id: str
    data: _containers.MessageMap[str, ExecutionValue]
    def __init__(self, execution_id: _Optional[str] = ..., data: _Optional[_Mapping[str, ExecutionValue]] = ...) -> None: ...

class ExecutionValue(_message.Message):
    __slots__ = ("value", "is_secret")
    VALUE_FIELD_NUMBER: _ClassVar[int]
    IS_SECRET_FIELD_NUMBER: _ClassVar[int]
    value: str
    is_secret: bool
    def __init__(self, value: _Optional[str] = ..., is_secret: bool = ...) -> None: ...



from ai.stigmer.agentic.agentexecution.v1 import approval_pb2 as _approval_pb2
from ai.stigmer.agentic.workflowexecution.v1 import enum_pb2 as _enum_pb2
from ai.stigmer.agentic.workflowexecution.v1 import spec_pb2 as _spec_pb2
from ai.stigmer.commons.apiresource import metadata_pb2 as _metadata_pb2
from ai.stigmer.commons.apiresource import status_pb2 as _status_pb2
from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class WorkflowExecution(_message.Message):
    __slots__ = ("api_version", "kind", "metadata", "spec", "status")
    API_VERSION_FIELD_NUMBER: _ClassVar[int]
    KIND_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SPEC_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    api_version: str
    kind: str
    metadata: _metadata_pb2.ApiResourceMetadata
    spec: _spec_pb2.WorkflowExecutionSpec
    status: WorkflowExecutionStatus
    def __init__(self, api_version: _Optional[str] = ..., kind: _Optional[str] = ..., metadata: _Optional[_Union[_metadata_pb2.ApiResourceMetadata, _Mapping]] = ..., spec: _Optional[_Union[_spec_pb2.WorkflowExecutionSpec, _Mapping]] = ..., status: _Optional[_Union[WorkflowExecutionStatus, _Mapping]] = ...) -> None: ...

class WorkflowExecutionStatus(_message.Message):
    __slots__ = ("audit", "phase", "tasks", "output", "error", "started_at", "completed_at", "temporal_workflow_id", "pending_approvals")
    AUDIT_FIELD_NUMBER: _ClassVar[int]
    PHASE_FIELD_NUMBER: _ClassVar[int]
    TASKS_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    STARTED_AT_FIELD_NUMBER: _ClassVar[int]
    COMPLETED_AT_FIELD_NUMBER: _ClassVar[int]
    TEMPORAL_WORKFLOW_ID_FIELD_NUMBER: _ClassVar[int]
    PENDING_APPROVALS_FIELD_NUMBER: _ClassVar[int]
    audit: _status_pb2.ApiResourceAudit
    phase: _enum_pb2.ExecutionPhase
    tasks: _containers.RepeatedCompositeFieldContainer[WorkflowTask]
    output: _struct_pb2.Struct
    error: str
    started_at: str
    completed_at: str
    temporal_workflow_id: str
    pending_approvals: _containers.RepeatedCompositeFieldContainer[_approval_pb2.PendingApproval]
    def __init__(self, audit: _Optional[_Union[_status_pb2.ApiResourceAudit, _Mapping]] = ..., phase: _Optional[_Union[_enum_pb2.ExecutionPhase, str]] = ..., tasks: _Optional[_Iterable[_Union[WorkflowTask, _Mapping]]] = ..., output: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., error: _Optional[str] = ..., started_at: _Optional[str] = ..., completed_at: _Optional[str] = ..., temporal_workflow_id: _Optional[str] = ..., pending_approvals: _Optional[_Iterable[_Union[_approval_pb2.PendingApproval, _Mapping]]] = ...) -> None: ...

class WorkflowTask(_message.Message):
    __slots__ = ("task_id", "task_name", "task_type", "input", "output", "status", "started_at", "completed_at", "error", "metadata")
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    TASK_NAME_FIELD_NUMBER: _ClassVar[int]
    TASK_TYPE_FIELD_NUMBER: _ClassVar[int]
    INPUT_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    STARTED_AT_FIELD_NUMBER: _ClassVar[int]
    COMPLETED_AT_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    task_id: str
    task_name: str
    task_type: _enum_pb2.WorkflowTaskType
    input: _struct_pb2.Struct
    output: _struct_pb2.Struct
    status: _enum_pb2.WorkflowTaskStatus
    started_at: str
    completed_at: str
    error: str
    metadata: _struct_pb2.Struct
    def __init__(self, task_id: _Optional[str] = ..., task_name: _Optional[str] = ..., task_type: _Optional[_Union[_enum_pb2.WorkflowTaskType, str]] = ..., input: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., output: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., status: _Optional[_Union[_enum_pb2.WorkflowTaskStatus, str]] = ..., started_at: _Optional[str] = ..., completed_at: _Optional[str] = ..., error: _Optional[str] = ..., metadata: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...



from ai.stigmer.agentic.agentexecution.v1 import approval_pb2 as _approval_pb2
from ai.stigmer.agentic.agentexecution.v1 import artifact_pb2 as _artifact_pb2
from ai.stigmer.agentic.agentexecution.v1 import context_pb2 as _context_pb2
from ai.stigmer.agentic.agentexecution.v1 import enum_pb2 as _enum_pb2
from ai.stigmer.agentic.agentexecution.v1 import message_pb2 as _message_pb2
from ai.stigmer.agentic.agentexecution.v1 import spec_pb2 as _spec_pb2
from ai.stigmer.agentic.agentexecution.v1 import subagent_pb2 as _subagent_pb2
from ai.stigmer.agentic.agentexecution.v1 import usage_pb2 as _usage_pb2
from ai.stigmer.commons.apiresource import metadata_pb2 as _metadata_pb2
from ai.stigmer.commons.apiresource import status_pb2 as _status_pb2
from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AgentExecution(_message.Message):
    __slots__ = ("api_version", "kind", "metadata", "spec", "status")
    API_VERSION_FIELD_NUMBER: _ClassVar[int]
    KIND_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SPEC_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    api_version: str
    kind: str
    metadata: _metadata_pb2.ApiResourceMetadata
    spec: _spec_pb2.AgentExecutionSpec
    status: AgentExecutionStatus
    def __init__(self, api_version: _Optional[str] = ..., kind: _Optional[str] = ..., metadata: _Optional[_Union[_metadata_pb2.ApiResourceMetadata, _Mapping]] = ..., spec: _Optional[_Union[_spec_pb2.AgentExecutionSpec, _Mapping]] = ..., status: _Optional[_Union[AgentExecutionStatus, _Mapping]] = ...) -> None: ...

class AgentExecutionStatus(_message.Message):
    __slots__ = ("audit", "messages", "phase", "tool_calls", "sub_agent_executions", "error", "started_at", "completed_at", "todos", "callback_token", "usage", "resolved_context", "pending_approvals", "context_info", "artifacts")
    class TodosEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: TodoItem
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[TodoItem, _Mapping]] = ...) -> None: ...
    AUDIT_FIELD_NUMBER: _ClassVar[int]
    MESSAGES_FIELD_NUMBER: _ClassVar[int]
    PHASE_FIELD_NUMBER: _ClassVar[int]
    TOOL_CALLS_FIELD_NUMBER: _ClassVar[int]
    SUB_AGENT_EXECUTIONS_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    STARTED_AT_FIELD_NUMBER: _ClassVar[int]
    COMPLETED_AT_FIELD_NUMBER: _ClassVar[int]
    TODOS_FIELD_NUMBER: _ClassVar[int]
    CALLBACK_TOKEN_FIELD_NUMBER: _ClassVar[int]
    USAGE_FIELD_NUMBER: _ClassVar[int]
    RESOLVED_CONTEXT_FIELD_NUMBER: _ClassVar[int]
    PENDING_APPROVALS_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_INFO_FIELD_NUMBER: _ClassVar[int]
    ARTIFACTS_FIELD_NUMBER: _ClassVar[int]
    audit: _status_pb2.ApiResourceAudit
    messages: _containers.RepeatedCompositeFieldContainer[_message_pb2.AgentMessage]
    phase: _enum_pb2.ExecutionPhase
    tool_calls: _containers.RepeatedCompositeFieldContainer[_message_pb2.ToolCall]
    sub_agent_executions: _containers.RepeatedCompositeFieldContainer[_subagent_pb2.SubAgentExecution]
    error: str
    started_at: str
    completed_at: str
    todos: _containers.MessageMap[str, TodoItem]
    callback_token: bytes
    usage: _usage_pb2.UsageMetrics
    resolved_context: _context_pb2.ResolvedExecutionContext
    pending_approvals: _containers.RepeatedCompositeFieldContainer[_approval_pb2.PendingApproval]
    context_info: _context_pb2.ContextInfo
    artifacts: _containers.RepeatedCompositeFieldContainer[_artifact_pb2.ExecutionArtifact]
    def __init__(self, audit: _Optional[_Union[_status_pb2.ApiResourceAudit, _Mapping]] = ..., messages: _Optional[_Iterable[_Union[_message_pb2.AgentMessage, _Mapping]]] = ..., phase: _Optional[_Union[_enum_pb2.ExecutionPhase, str]] = ..., tool_calls: _Optional[_Iterable[_Union[_message_pb2.ToolCall, _Mapping]]] = ..., sub_agent_executions: _Optional[_Iterable[_Union[_subagent_pb2.SubAgentExecution, _Mapping]]] = ..., error: _Optional[str] = ..., started_at: _Optional[str] = ..., completed_at: _Optional[str] = ..., todos: _Optional[_Mapping[str, TodoItem]] = ..., callback_token: _Optional[bytes] = ..., usage: _Optional[_Union[_usage_pb2.UsageMetrics, _Mapping]] = ..., resolved_context: _Optional[_Union[_context_pb2.ResolvedExecutionContext, _Mapping]] = ..., pending_approvals: _Optional[_Iterable[_Union[_approval_pb2.PendingApproval, _Mapping]]] = ..., context_info: _Optional[_Union[_context_pb2.ContextInfo, _Mapping]] = ..., artifacts: _Optional[_Iterable[_Union[_artifact_pb2.ExecutionArtifact, _Mapping]]] = ...) -> None: ...

class TodoItem(_message.Message):
    __slots__ = ("id", "content", "status", "created_at", "updated_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    content: str
    status: _enum_pb2.TodoStatus
    created_at: str
    updated_at: str
    def __init__(self, id: _Optional[str] = ..., content: _Optional[str] = ..., status: _Optional[_Union[_enum_pb2.TodoStatus, str]] = ..., created_at: _Optional[str] = ..., updated_at: _Optional[str] = ...) -> None: ...



from ai.stigmer.commons.apiresource import field_options_pb2 as _field_options_pb2
from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class HttpCallTaskConfig(_message.Message):
    __slots__ = ("method", "endpoint", "headers", "body", "timeout_seconds")
    class HeadersEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    METHOD_FIELD_NUMBER: _ClassVar[int]
    ENDPOINT_FIELD_NUMBER: _ClassVar[int]
    HEADERS_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_SECONDS_FIELD_NUMBER: _ClassVar[int]
    method: str
    endpoint: HttpEndpoint
    headers: _containers.ScalarMap[str, str]
    body: _struct_pb2.Struct
    timeout_seconds: int
    def __init__(self, method: _Optional[str] = ..., endpoint: _Optional[_Union[HttpEndpoint, _Mapping]] = ..., headers: _Optional[_Mapping[str, str]] = ..., body: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., timeout_seconds: _Optional[int] = ...) -> None: ...

class HttpEndpoint(_message.Message):
    __slots__ = ("uri",)
    URI_FIELD_NUMBER: _ClassVar[int]
    uri: str
    def __init__(self, uri: _Optional[str] = ...) -> None: ...



from ai.stigmer.agentic.skill.v1 import status_pb2 as _status_pb2
from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SkillId(_message.Message):
    __slots__ = ("value",)
    VALUE_FIELD_NUMBER: _ClassVar[int]
    value: str
    def __init__(self, value: _Optional[str] = ...) -> None: ...

class PushSkillRequest(_message.Message):
    __slots__ = ("org", "artifact", "tag", "git_provenance")
    ORG_FIELD_NUMBER: _ClassVar[int]
    ARTIFACT_FIELD_NUMBER: _ClassVar[int]
    TAG_FIELD_NUMBER: _ClassVar[int]
    GIT_PROVENANCE_FIELD_NUMBER: _ClassVar[int]
    org: str
    artifact: bytes
    tag: str
    git_provenance: _status_pb2.GitProvenance
    def __init__(self, org: _Optional[str] = ..., artifact: _Optional[bytes] = ..., tag: _Optional[str] = ..., git_provenance: _Optional[_Union[_status_pb2.GitProvenance, _Mapping]] = ...) -> None: ...

class PushSkillFromExecutionArtifactRequest(_message.Message):
    __slots__ = ("org", "execution_id", "storage_key", "tag")
    ORG_FIELD_NUMBER: _ClassVar[int]
    EXECUTION_ID_FIELD_NUMBER: _ClassVar[int]
    STORAGE_KEY_FIELD_NUMBER: _ClassVar[int]
    TAG_FIELD_NUMBER: _ClassVar[int]
    org: str
    execution_id: str
    storage_key: str
    tag: str
    def __init__(self, org: _Optional[str] = ..., execution_id: _Optional[str] = ..., storage_key: _Optional[str] = ..., tag: _Optional[str] = ...) -> None: ...

class GetArtifactRequest(_message.Message):
    __slots__ = ("artifact_storage_key",)
    ARTIFACT_STORAGE_KEY_FIELD_NUMBER: _ClassVar[int]
    artifact_storage_key: str
    def __init__(self, artifact_storage_key: _Optional[str] = ...) -> None: ...

class GetArtifactResponse(_message.Message):
    __slots__ = ("artifact",)
    ARTIFACT_FIELD_NUMBER: _ClassVar[int]
    artifact: bytes
    def __init__(self, artifact: _Optional[bytes] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/workflowexecution/v1/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/workflowexecution/v1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.workflowexecution.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2
from ai.stigmer.agentic.workflowexecution.v1 import io_pb2 as ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_io__pb2
from ai.stigmer.commons.apiresource import rpc_service_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_rpc__service__options__pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_method__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3ai/stigmer/agentic/workflowexecution/v1/query.proto\x12\'ai.stigmer.agentic.workflowexecution.v1\x1a\x31\x61i/stigmer/agentic/workflowexecution/v1/api.proto\x1a\x30\x61i/stigmer/agentic/workflowexecution/v1/io.proto\x1a\x38\x61i/stigmer/commons/apiresource/rpc_service_options.proto\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto2\x84\x06\n WorkflowExecutionQueryController\x12\xb8\x01\n\x03get\x12<.ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionId\x1a:.ai.stigmer.agentic.workflowexecution.v1.WorkflowExecution\"7\xc2\xb8\x18\x33\x08\x03\x10\x34\"\x05value*&unauthorized to get workflow execution\x12\x94\x01\n\x04list\x12\x46.ai.stigmer.agentic.workflowexecution.v1.ListWorkflowExecutionsRequest\x1a>.ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionList\"\x04\xd0\xb8\x18\x01\x12\xa8\x01\n\x0elistByWorkflow\x12P.ai.stigmer.agentic.workflowexecution.v1.ListWorkflowExecutionsByWorkflowRequest\x1a>.ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionList\"\x04\xd0\xb8\x18\x01\x12\xdc\x01\n\tsubscribe\x12J.ai.stigmer.agentic.workflowexecution.v1.SubscribeWorkflowExecutionRequest\x1a:.ai.stigmer.agentic.workflowexecution.v1.WorkflowExecution\"E\xc2\xb8\x18\x41\x08\x03\x10\x34\"\x0c\x65xecution_id*-unauthorized to get workflow execution stream0\x01\x1a\x04\xa0\xff+4B\xfa\x01\n+com.ai.stigmer.agentic.workflowexecution.v1B\nQueryProtoP\x01\xa2\x02\x04\x41SAW\xaa\x02\'Ai.Stigmer.Agentic.Workflowexecution.V1\xca\x02\'Ai\\Stigmer\\Agentic\\Workflowexecution\\V1\xe2\x02\x33\x41i\\Stigmer\\Agentic\\Workflowexecution\\V1\\GPBMetadata\xea\x02+Ai::Stigmer::Agentic::Workflowexecution::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.workflowexecution.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+com.ai.stigmer.agentic.workflowexecution.v1B\nQueryProtoP\001\242\002\004ASAW\252\002\'Ai.Stigmer.Agentic.Workflowexecution.V1\312\002\'Ai\\Stigmer\\Agentic\\Workflowexecution\\V1\342\0023Ai\\Stigmer\\Agentic\\Workflowexecution\\V1\\GPBMetadata\352\002+Ai::Stigmer::Agentic::Workflowexecution::V1'
  _globals['_WORKFLOWEXECUTIONQUERYCONTROLLER']._loaded_options = None
  _globals['_WORKFLOWEXECUTIONQUERYCONTROLLER']._serialized_options = b'\240\377+4'
  _globals['_WORKFLOWEXECUTIONQUERYCONTROLLER'].methods_by_name['get']._loaded_options = None
  _globals['_WORKFLOWEXECUTIONQUERYCONTROLLER'].methods_by_name['get']._serialized_options = b'\302\270\0303\010\003\0204\"\005value*&unauthorized to get workflow execution'
  _globals['_WORKFLOWEXECUTIONQUERYCONTROLLER'].methods_by_name['list']._loaded_options = None
  _globals['_WORKFLOWEXECUTIONQUERYCONTROLLER'].methods_by_name['list']._serialized_options = b'\320\270\030\001'
  _globals['_WORKFLOWEXECUTIONQUERYCONTROLLER'].methods_by_name['listByWorkflow']._loaded_options = None
  _globals['_WORKFLOWEXECUTIONQUERYCONTROLLER'].methods_by_name['listByWorkflow']._serialized_options = b'\320\270\030\001'
  _globals['_WORKFLOWEXECUTIONQUERYCONTROLLER'].methods_by_name['subscribe']._loaded_options = None
  _globals['_WORKFLOWEXECUTIONQUERYCONTROLLER'].methods_by_name['subscribe']._serialized_options = b'\302\270\030A\010\003\0204\"\014execution_id*-unauthorized to get workflow execution stream'
  _globals['_WORKFLOWEXECUTIONQUERYCONTROLLER']._serialized_start=323
  _globals['_WORKFLOWEXECUTIONQUERYCONTROLLER']._serialized_end=1095
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/commons/apiresource/enum.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/commons/apiresource/enum.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)ai/stigmer/commons/apiresource/enum.proto\x12\x1e\x61i.stigmer.commons.apiresource*v\n\x14\x41piResourceEventType\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07\x63reated\x10\x01\x12\x0b\n\x07updated\x10\x02\x12\x0b\n\x07\x64\x65leted\x10\x03\x12\x0b\n\x07renamed\x10\x04\x12\x19\n\x15stack_outputs_updated\x10\x05*\x8c\x01\n\x1d\x41piResourceStateOperationType\x12\x31\n-api_resource_state_operation_type_unspecified\x10\x00\x12\n\n\x06\x63reate\x10\x01\x12\n\n\x06update\x10\x02\x12\n\n\x06\x64\x65lete\x10\x03\x12\x08\n\x04read\x10\x04\x12\n\n\x06stream\x10\x05*o\n\x15\x41piResourceVisibility\x12\'\n#api_resource_visibility_unspecified\x10\x00\x12\x16\n\x12visibility_private\x10\x01\x12\x15\n\x11visibility_public\x10\x02\x42\xcb\x01\n\"com.ai.stigmer.commons.apiresourceB\tEnumProtoP\x01\xa2\x02\x04\x41SCA\xaa\x02\x1e\x41i.Stigmer.Commons.Apiresource\xca\x02\x1e\x41i\\Stigmer\\Commons\\Apiresource\xe2\x02*Ai\\Stigmer\\Commons\\Apiresource\\GPBMetadata\xea\x02!Ai::Stigmer::Commons::Apiresourceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.commons.apiresource.enum_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"com.ai.stigmer.commons.apiresourceB\tEnumProtoP\001\242\002\004ASCA\252\002\036Ai.Stigmer.Commons.Apiresource\312\002\036Ai\\Stigmer\\Commons\\Apiresource\342\002*Ai\\Stigmer\\Commons\\Apiresource\\GPBMetadata\352\002!Ai::Stigmer::Commons::Apiresource'
  _globals['_APIRESOURCEEVENTTYPE']._serialized_start=77
  _globals['_APIRESOURCEEVENTTYPE']._serialized_end=195
  _globals['_APIRESOURCESTATEOPERATIONTYPE']._serialized_start=198
  _globals['_APIRESOURCESTATEOPERATIONTYPE']._serialized_end=338
  _globals['_APIRESOURCEVISIBILITY']._serialized_start=340
  _globals['_APIRESOURCEVISIBILITY']._serialized_end=451
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class ExecutionPhase(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    EXECUTION_PHASE_UNSPECIFIED: _ClassVar[ExecutionPhase]
    EXECUTION_PENDING: _ClassVar[ExecutionPhase]
    EXECUTION_IN_PROGRESS: _ClassVar[ExecutionPhase]
    EXECUTION_COMPLETED: _ClassVar[ExecutionPhase]
    EXECUTION_FAILED: _ClassVar[ExecutionPhase]
    EXECUTION_CANCELLED: _ClassVar[ExecutionPhase]
    EXECUTION_TERMINATED: _ClassVar[ExecutionPhase]
    EXECUTION_WAITING_FOR_APPROVAL: _ClassVar[ExecutionPhase]
    EXECUTION_PAUSED: _ClassVar[ExecutionPhase]

class MessageType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    MESSAGE_TYPE_UNSPECIFIED: _ClassVar[MessageType]
    MESSAGE_HUMAN: _ClassVar[MessageType]
    MESSAGE_AI: _ClassVar[MessageType]
    MESSAGE_TOOL: _ClassVar[MessageType]
    MESSAGE_SYSTEM: _ClassVar[MessageType]

class ToolCallStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    TOOL_CALL_STATUS_UNSPECIFIED: _ClassVar[ToolCallStatus]
    TOOL_CALL_PENDING: _ClassVar[ToolCallStatus]
    TOOL_CALL_RUNNING: _ClassVar[ToolCallStatus]
    TOOL_CALL_COMPLETED: _ClassVar[ToolCallStatus]
    TOOL_CALL_FAILED: _ClassVar[ToolCallStatus]
    TOOL_CALL_WAITING_APPROVAL: _ClassVar[ToolCallStatus]
    TOOL_CALL_SKIPPED: _ClassVar[ToolCallStatus]

class TodoStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    TODO_STATUS_UNSPECIFIED: _ClassVar[TodoStatus]
    TODO_PENDING: _ClassVar[TodoStatus]
    TODO_IN_PROGRESS: _ClassVar[TodoStatus]
    TODO_COMPLETED: _ClassVar[TodoStatus]
    TODO_CANCELLED: _ClassVar[TodoStatus]

class SubAgentStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SUB_AGENT_STATUS_UNSPECIFIED: _ClassVar[SubAgentStatus]
    SUB_AGENT_PENDING: _ClassVar[SubAgentStatus]
    SUB_AGENT_IN_PROGRESS: _ClassVar[SubAgentStatus]
    SUB_AGENT_COMPLETED: _ClassVar[SubAgentStatus]
    SUB_AGENT_FAILED: _ClassVar[SubAgentStatus]
    SUB_AGENT_CANCELLED: _ClassVar[SubAgentStatus]

class ExecutionArtifactKind(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    EXECUTION_ARTIFACT_KIND_UNSPECIFIED: _ClassVar[ExecutionArtifactKind]
    EXECUTION_ARTIFACT_KIND_FILE: _ClassVar[ExecutionArtifactKind]
    EXECUTION_ARTIFACT_KIND_DIRECTORY: _ClassVar[ExecutionArtifactKind]

class SummarizationSource(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SUMMARIZATION_SOURCE_UNSPECIFIED: _ClassVar[SummarizationSource]
    graph_start: _ClassVar[SummarizationSource]
    mid_execution: _ClassVar[SummarizationSource]

class ApprovalAction(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    APPROVAL_ACTION_UNSPECIFIED: _ClassVar[ApprovalAction]
    APPROVAL_ACTION_APPROVE: _ClassVar[ApprovalAction]
    APPROVAL_ACTION_SKIP: _ClassVar[ApprovalAction]
    APPROVAL_ACTION_REJECT: _ClassVar[ApprovalAction]
EXECUTION_PHASE_UNSPECIFIED: ExecutionPhase
EXECUTION_PENDING: ExecutionPhase
EXECUTION_IN_PROGRESS: ExecutionPhase
EXECUTION_COMPLETED: ExecutionPhase
EXECUTION_FAILED: ExecutionPhase
EXECUTION_CANCELLED: ExecutionPhase
EXECUTION_TERMINATED: ExecutionPhase
EXECUTION_WAITING_FOR_APPROVAL: ExecutionPhase
EXECUTION_PAUSED: ExecutionPhase
MESSAGE_TYPE_UNSPECIFIED: MessageType
MESSAGE_HUMAN: MessageType
MESSAGE_AI: MessageType
MESSAGE_TOOL: MessageType
MESSAGE_SYSTEM: MessageType
TOOL_CALL_STATUS_UNSPECIFIED: ToolCallStatus
TOOL_CALL_PENDING: ToolCallStatus
TOOL_CALL_RUNNING: ToolCallStatus
TOOL_CALL_COMPLETED: ToolCallStatus
TOOL_CALL_FAILED: ToolCallStatus
TOOL_CALL_WAITING_APPROVAL: ToolCallStatus
TOOL_CALL_SKIPPED: ToolCallStatus
TODO_STATUS_UNSPECIFIED: TodoStatus
TODO_PENDING: TodoStatus
TODO_IN_PROGRESS: TodoStatus
TODO_COMPLETED: TodoStatus
TODO_CANCELLED: TodoStatus
SUB_AGENT_STATUS_UNSPECIFIED: SubAgentStatus
SUB_AGENT_PENDING: SubAgentStatus
SUB_AGENT_IN_PROGRESS: SubAgentStatus
SUB_AGENT_COMPLETED: SubAgentStatus
SUB_AGENT_FAILED: SubAgentStatus
SUB_AGENT_CANCELLED: SubAgentStatus
EXECUTION_ARTIFACT_KIND_UNSPECIFIED: ExecutionArtifactKind
EXECUTION_ARTIFACT_KIND_FILE: ExecutionArtifactKind
EXECUTION_ARTIFACT_KIND_DIRECTORY: ExecutionArtifactKind
SUMMARIZATION_SOURCE_UNSPECIFIED: SummarizationSource
graph_start: SummarizationSource
mid_execution: SummarizationSource
APPROVAL_ACTION_UNSPECIFIED: ApprovalAction
APPROVAL_ACTION_APPROVE: ApprovalAction
APPROVAL_ACTION_SKIP: ApprovalAction
APPROVAL_ACTION_REJECT: ApprovalAction



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/workflow/v1/tasks/try.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/workflow/v1/tasks/try.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.workflow.v1 import spec_pb2 as ai_dot_stigmer_dot_agentic_dot_workflow_dot_v1_dot_spec__pb2
from ai.stigmer.commons.apiresource import field_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_field__options__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.ai/stigmer/agentic/workflow/v1/tasks/try.proto\x12$ai.stigmer.agentic.workflow.v1.tasks\x1a)ai/stigmer/agentic/workflow/v1/spec.proto\x1a\x32\x61i/stigmer/commons/apiresource/field_options.proto\x1a\x1b\x62uf/validate/validate.proto\"\xb0\x01\n\rTryTaskConfig\x12H\n\x03try\x18\x01 \x03(\x0b\x32,.ai.stigmer.agentic.workflow.v1.WorkflowTaskB\x08\xbaH\x05\x92\x01\x02\x08\x01R\x03try\x12\x46\n\x05\x63\x61tch\x18\x02 \x01(\x0b\x32\x30.ai.stigmer.agentic.workflow.v1.tasks.CatchBlockR\x05\x63\x61tch:\r\xea\x8b,\ttry_catch\"d\n\nCatchBlock\x12\x0e\n\x02\x61s\x18\x01 \x01(\tR\x02\x61s\x12\x46\n\x02\x64o\x18\x02 \x03(\x0b\x32,.ai.stigmer.agentic.workflow.v1.WorkflowTaskB\x08\xbaH\x05\x92\x01\x02\x08\x01R\x02\x64oB\xec\x01\n(com.ai.stigmer.agentic.workflow.v1.tasksB\x08TryProtoP\x01\xa2\x02\x06\x41SAWVT\xaa\x02$Ai.Stigmer.Agentic.Workflow.V1.Tasks\xca\x02$Ai\\Stigmer\\Agentic\\Workflow\\V1\\Tasks\xe2\x02\x30\x41i\\Stigmer\\Agentic\\Workflow\\V1\\Tasks\\GPBMetadata\xea\x02)Ai::Stigmer::Agentic::Workflow::V1::Tasksb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.workflow.v1.tasks.try_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(com.ai.stigmer.agentic.workflow.v1.tasksB\010TryProtoP\001\242\002\006ASAWVT\252\002$Ai.Stigmer.Agentic.Workflow.V1.Tasks\312\002$Ai\\Stigmer\\Agentic\\Workflow\\V1\\Tasks\342\0020Ai\\Stigmer\\Agentic\\Workflow\\V1\\Tasks\\GPBMetadata\352\002)Ai::Stigmer::Agentic::Workflow::V1::Tasks'
  _globals['_TRYTASKCONFIG'].fields_by_name['try']._loaded_options = None
  _globals['_TRYTASKCONFIG'].fields_by_name['try']._serialized_options = b'\272H\005\222\001\002\010\001'
  _globals['_TRYTASKCONFIG']._loaded_options = None
  _globals['_TRYTASKCONFIG']._serialized_options = b'\352\213,\ttry_catch'
  _globals['_CATCHBLOCK'].fields_by_name['do']._loaded_options = None
  _globals['_CATCHBLOCK'].fields_by_name['do']._serialized_options = b'\272H\005\222\001\002\010\001'
  _globals['_TRYTASKCONFIG']._serialized_start=213
  _globals['_TRYTASKCONFIG']._serialized_end=389
  _globals['_CATCHBLOCK']._serialized_start=391
  _globals['_CATCHBLOCK']._serialized_end=491
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class ManagementMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    management_mode_unspecified: _ClassVar[ManagementMode]
    self_managed: _ClassVar[ManagementMode]
    platform_managed: _ClassVar[ManagementMode]
management_mode_unspecified: ManagementMode
self_managed: ManagementMode
platform_managed: ManagementMode



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ai.stigmer.agentic.skill.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_api__pb2
from ai.stigmer.agentic.skill.v1 import io_pb2 as ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_io__pb2
from ai.stigmer.commons.apiresource import io_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2


class SkillCommandControllerStub(object):
    """SkillCommandController handles write operations for skills.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.push = channel.unary_unary(
                '/ai.stigmer.agentic.skill.v1.SkillCommandController/push',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_io__pb2.PushSkillRequest.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_api__pb2.Skill.FromString,
                _registered_method=True)
        self.pushFromExecutionArtifact = channel.unary_unary(
                '/ai.stigmer.agentic.skill.v1.SkillCommandController/pushFromExecutionArtifact',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_io__pb2.PushSkillFromExecutionArtifactRequest.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_api__pb2.Skill.FromString,
                _registered_method=True)
        self.updateVisibility = channel.unary_unary(
                '/ai.stigmer.agentic.skill.v1.SkillCommandController/updateVisibility',
                request_serializer=ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2.UpdateVisibilityInput.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_api__pb2.Skill.FromString,
                _registered_method=True)
        self.delete = channel.unary_unary(
                '/ai.stigmer.agentic.skill.v1.SkillCommandController/delete',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_io__pb2.SkillId.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_api__pb2.Skill.FromString,
                _registered_method=True)


class SkillCommandControllerServicer(object):
    """SkillCommandController handles write operations for skills.
    """

    def push(self, request, context):
        """Push (upload) a skill artifact.
        This operation creates a new skill if it doesn't exist, or creates a new version
        of an existing skill. The skill artifact must contain SKILL.md.

        Authorization:
        - Organization-scoped skills: Caller must have can_create_skill permission in the organization
        - Platform-scoped skills: Caller must be a platform operator (handled automatically by common auth step)

        The backend will:
        1. Normalize the name to a slug
        2. Find or create the skill resource
        3. Extract SKILL.md from the artifact
        4. Calculate SHA256 hash (version identifier)
        5. Store the artifact (deduplicated by hash)
        6. Update skill spec and status
        7. Archive the previous version (if updating)

        Returns: The created or updated Skill resource (consistent with other CRUD operations)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def pushFromExecutionArtifact(self, request, context):
        """Push a skill directly from an execution artifact already in storage.

        This is the server-side equivalent of push() — instead of receiving
        ZIP bytes from the client, it reads an existing directory artifact
        (produced by an agent execution) from artifact storage and pushes
        it as a skill. This avoids downloading the ZIP to the browser and
        re-uploading it, and eliminates CORS concerns for SDK consumers.

        The caller must have can_view on the referenced execution AND
        can_create_skill in the target organization.

        Returns: The created or updated Skill resource
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def updateVisibility(self, request, context):
        """Update the visibility of an existing skill.

        This is a targeted metadata update — it only modifies metadata.visibility,
        leaving spec, status, and other metadata fields untouched. Skills default
        to visibility_private on push; use this RPC to make a skill publicly
        accessible (marketplace-style sharing) or to revoke public access.

        Authorization: Requires can_edit permission on the skill resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """Delete a skill and all its versions.
        This removes the skill from the main collection but preserves audit history.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SkillCommandControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'push': grpc.unary_unary_rpc_method_handler(
                    servicer.push,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_io__pb2.PushSkillRequest.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_api__pb2.Skill.SerializeToString,
            ),
            'pushFromExecutionArtifact': grpc.unary_unary_rpc_method_handler(
                    servicer.pushFromExecutionArtifact,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_io__pb2.PushSkillFromExecutionArtifactRequest.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_api__pb2.Skill.SerializeToString,
            ),
            'updateVisibility': grpc.unary_unary_rpc_method_handler(
                    servicer.updateVisibility,
                    request_deserializer=ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2.UpdateVisibilityInput.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_api__pb2.Skill.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_io__pb2.SkillId.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_api__pb2.Skill.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ai.stigmer.agentic.skill.v1.SkillCommandController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('ai.stigmer.agentic.skill.v1.SkillCommandController', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class SkillCommandController(object):
    """SkillCommandController handles write operations for skills.
    """

    @staticmethod
    def push(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.skill.v1.SkillCommandController/push',
            ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_io__pb2.PushSkillRequest.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_api__pb2.Skill.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def pushFromExecutionArtifact(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.skill.v1.SkillCommandController/pushFromExecutionArtifact',
            ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_io__pb2.PushSkillFromExecutionArtifactRequest.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_api__pb2.Skill.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def updateVisibility(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.skill.v1.SkillCommandController/updateVisibility',
            ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2.UpdateVisibilityInput.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_api__pb2.Skill.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.skill.v1.SkillCommandController/delete',
            ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_io__pb2.SkillId.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_api__pb2.Skill.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ai.stigmer.iam.identityaccount.v1 import api_pb2 as ai_dot_stigmer_dot_iam_dot_identityaccount_dot_v1_dot_api__pb2
from ai.stigmer.iam.identityaccount.v1 import io_pb2 as ai_dot_stigmer_dot_iam_dot_identityaccount_dot_v1_dot_io__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class IdentityAccountCommandControllerStub(object):
    """identity-account command controller
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/ai.stigmer.iam.identityaccount.v1.IdentityAccountCommandController/create',
                request_serializer=ai_dot_stigmer_dot_iam_dot_identityaccount_dot_v1_dot_api__pb2.IdentityAccount.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_iam_dot_identityaccount_dot_v1_dot_api__pb2.IdentityAccount.FromString,
                _registered_method=True)
        self.update = channel.unary_unary(
                '/ai.stigmer.iam.identityaccount.v1.IdentityAccountCommandController/update',
                request_serializer=ai_dot_stigmer_dot_iam_dot_identityaccount_dot_v1_dot_api__pb2.IdentityAccount.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_iam_dot_identityaccount_dot_v1_dot_api__pb2.IdentityAccount.FromString,
                _registered_method=True)
        self.delete = channel.unary_unary(
                '/ai.stigmer.iam.identityaccount.v1.IdentityAccountCommandController/delete',
                request_serializer=ai_dot_stigmer_dot_iam_dot_identityaccount_dot_v1_dot_io__pb2.IdentityAccountId.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_iam_dot_identityaccount_dot_v1_dot_api__pb2.IdentityAccount.FromString,
                _registered_method=True)
        self.simulateSignupWebhook = channel.unary_unary(
                '/ai.stigmer.iam.identityaccount.v1.IdentityAccountCommandController/simulateSignupWebhook',
                request_serializer=ai_dot_stigmer_dot_iam_dot_identityaccount_dot_v1_dot_io__pb2.IdentityAccountEmail.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)


class IdentityAccountCommandControllerServicer(object):
    """identity-account command controller
    """

    def create(self, request, context):
        """create a new identity-account.
        system-level RPC used by federated JIT provisioning and Auth0 webhook flow.
        no FGA authorization — called via inProcessChannelAsSystem (machine account).
        the handler's createAuthorizationTuples step writes the self-ownership tuple after creation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """update an existing identity-account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """delete an existing identity-account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def simulateSignupWebhook(self, request, context):
        """simulate signup webhook to add a user who created account on auth0 but is not created on stigmer.
        this rpc will take the email, look it up on auth0,
        if there is a user with this email on auth0 and post a webhook to stigmer with auth0 payload format.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_IdentityAccountCommandControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=ai_dot_stigmer_dot_iam_dot_identityaccount_dot_v1_dot_api__pb2.IdentityAccount.FromString,
                    response_serializer=ai_dot_stigmer_dot_iam_dot_identityaccount_dot_v1_dot_api__pb2.IdentityAccount.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=ai_dot_stigmer_dot_iam_dot_identityaccount_dot_v1_dot_api__pb2.IdentityAccount.FromString,
                    response_serializer=ai_dot_stigmer_dot_iam_dot_identityaccount_dot_v1_dot_api__pb2.IdentityAccount.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=ai_dot_stigmer_dot_iam_dot_identityaccount_dot_v1_dot_io__pb2.IdentityAccountId.FromString,
                    response_serializer=ai_dot_stigmer_dot_iam_dot_identityaccount_dot_v1_dot_api__pb2.IdentityAccount.SerializeToString,
            ),
            'simulateSignupWebhook': grpc.unary_unary_rpc_method_handler(
                    servicer.simulateSignupWebhook,
                    request_deserializer=ai_dot_stigmer_dot_iam_dot_identityaccount_dot_v1_dot_io__pb2.IdentityAccountEmail.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ai.stigmer.iam.identityaccount.v1.IdentityAccountCommandController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('ai.stigmer.iam.identityaccount.v1.IdentityAccountCommandController', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class IdentityAccountCommandController(object):
    """identity-account command controller
    """

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.iam.identityaccount.v1.IdentityAccountCommandController/create',
            ai_dot_stigmer_dot_iam_dot_identityaccount_dot_v1_dot_api__pb2.IdentityAccount.SerializeToString,
            ai_dot_stigmer_dot_iam_dot_identityaccount_dot_v1_dot_api__pb2.IdentityAccount.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.iam.identityaccount.v1.IdentityAccountCommandController/update',
            ai_dot_stigmer_dot_iam_dot_identityaccount_dot_v1_dot_api__pb2.IdentityAccount.SerializeToString,
            ai_dot_stigmer_dot_iam_dot_identityaccount_dot_v1_dot_api__pb2.IdentityAccount.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.iam.identityaccount.v1.IdentityAccountCommandController/delete',
            ai_dot_stigmer_dot_iam_dot_identityaccount_dot_v1_dot_io__pb2.IdentityAccountId.SerializeToString,
            ai_dot_stigmer_dot_iam_dot_identityaccount_dot_v1_dot_api__pb2.IdentityAccount.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def simulateSignupWebhook(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.iam.identityaccount.v1.IdentityAccountCommandController/simulateSignupWebhook',
            ai_dot_stigmer_dot_iam_dot_identityaccount_dot_v1_dot_io__pb2.IdentityAccountEmail.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



from ai.stigmer.agentic.agentexecution.v1 import enum_pb2 as _enum_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ResolvedExecutionContext(_message.Message):
    __slots__ = ("environment_keys", "mcp_servers", "skill_names", "excluded_skill_names")
    class McpServersEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: McpServerResolutionStatus
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[McpServerResolutionStatus, _Mapping]] = ...) -> None: ...
    ENVIRONMENT_KEYS_FIELD_NUMBER: _ClassVar[int]
    MCP_SERVERS_FIELD_NUMBER: _ClassVar[int]
    SKILL_NAMES_FIELD_NUMBER: _ClassVar[int]
    EXCLUDED_SKILL_NAMES_FIELD_NUMBER: _ClassVar[int]
    environment_keys: _containers.RepeatedScalarFieldContainer[str]
    mcp_servers: _containers.MessageMap[str, McpServerResolutionStatus]
    skill_names: _containers.RepeatedScalarFieldContainer[str]
    excluded_skill_names: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, environment_keys: _Optional[_Iterable[str]] = ..., mcp_servers: _Optional[_Mapping[str, McpServerResolutionStatus]] = ..., skill_names: _Optional[_Iterable[str]] = ..., excluded_skill_names: _Optional[_Iterable[str]] = ...) -> None: ...

class McpServerResolutionStatus(_message.Message):
    __slots__ = ("resolved", "message", "enabled_tool_count")
    RESOLVED_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    ENABLED_TOOL_COUNT_FIELD_NUMBER: _ClassVar[int]
    resolved: bool
    message: str
    enabled_tool_count: int
    def __init__(self, resolved: bool = ..., message: _Optional[str] = ..., enabled_tool_count: _Optional[int] = ...) -> None: ...

class SummarizationEvent(_message.Message):
    __slots__ = ("timestamp", "tokens_before", "tokens_after", "compression_ratio", "duration_ms", "summarization_model", "messages_before", "messages_after", "source", "summarization_input_tokens", "summarization_output_tokens", "summarization_cost_usd")
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    TOKENS_BEFORE_FIELD_NUMBER: _ClassVar[int]
    TOKENS_AFTER_FIELD_NUMBER: _ClassVar[int]
    COMPRESSION_RATIO_FIELD_NUMBER: _ClassVar[int]
    DURATION_MS_FIELD_NUMBER: _ClassVar[int]
    SUMMARIZATION_MODEL_FIELD_NUMBER: _ClassVar[int]
    MESSAGES_BEFORE_FIELD_NUMBER: _ClassVar[int]
    MESSAGES_AFTER_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    SUMMARIZATION_INPUT_TOKENS_FIELD_NUMBER: _ClassVar[int]
    SUMMARIZATION_OUTPUT_TOKENS_FIELD_NUMBER: _ClassVar[int]
    SUMMARIZATION_COST_USD_FIELD_NUMBER: _ClassVar[int]
    timestamp: str
    tokens_before: int
    tokens_after: int
    compression_ratio: float
    duration_ms: int
    summarization_model: str
    messages_before: int
    messages_after: int
    source: _enum_pb2.SummarizationSource
    summarization_input_tokens: int
    summarization_output_tokens: int
    summarization_cost_usd: float
    def __init__(self, timestamp: _Optional[str] = ..., tokens_before: _Optional[int] = ..., tokens_after: _Optional[int] = ..., compression_ratio: _Optional[float] = ..., duration_ms: _Optional[int] = ..., summarization_model: _Optional[str] = ..., messages_before: _Optional[int] = ..., messages_after: _Optional[int] = ..., source: _Optional[_Union[_enum_pb2.SummarizationSource, str]] = ..., summarization_input_tokens: _Optional[int] = ..., summarization_output_tokens: _Optional[int] = ..., summarization_cost_usd: _Optional[float] = ...) -> None: ...

class ContextInfo(_message.Message):
    __slots__ = ("current_token_count", "context_window_limit", "summarization_trigger_threshold", "summarization_target_tokens", "summarization_enabled", "summarization_events", "utilization_percent")
    CURRENT_TOKEN_COUNT_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_WINDOW_LIMIT_FIELD_NUMBER: _ClassVar[int]
    SUMMARIZATION_TRIGGER_THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    SUMMARIZATION_TARGET_TOKENS_FIELD_NUMBER: _ClassVar[int]
    SUMMARIZATION_ENABLED_FIELD_NUMBER: _ClassVar[int]
    SUMMARIZATION_EVENTS_FIELD_NUMBER: _ClassVar[int]
    UTILIZATION_PERCENT_FIELD_NUMBER: _ClassVar[int]
    current_token_count: int
    context_window_limit: int
    summarization_trigger_threshold: int
    summarization_target_tokens: int
    summarization_enabled: bool
    summarization_events: _containers.RepeatedCompositeFieldContainer[SummarizationEvent]
    utilization_percent: float
    def __init__(self, current_token_count: _Optional[int] = ..., context_window_limit: _Optional[int] = ..., summarization_trigger_threshold: _Optional[int] = ..., summarization_target_tokens: _Optional[int] = ..., summarization_enabled: bool = ..., summarization_events: _Optional[_Iterable[_Union[SummarizationEvent, _Mapping]]] = ..., utilization_percent: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/tenancy/organization/v1/spec.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/tenancy/organization/v1/spec.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource import io_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2
from ai.stigmer.tenancy.organization.v1 import enum_pb2 as ai_dot_stigmer_dot_tenancy_dot_organization_dot_v1_dot_enum__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-ai/stigmer/tenancy/organization/v1/spec.proto\x12\"ai.stigmer.tenancy.organization.v1\x1a\'ai/stigmer/commons/apiresource/io.proto\x1a-ai/stigmer/tenancy/organization/v1/enum.proto\x1a\x1b\x62uf/validate/validate.proto\"\xf3\x02\n\x10OrganizationSpec\x12*\n\x0b\x64\x65scription\x18\x01 \x01(\tB\x08\xbaH\x05r\x03\x18\xf4\x03R\x0b\x64\x65scription\x12#\n\x08logo_url\x18\x02 \x01(\tB\x08\xbaH\x05r\x03\x18\x80\x10R\x07logoUrl\x12[\n\x0fmanagement_mode\x18\x03 \x01(\x0e\x32\x32.ai.stigmer.tenancy.organization.v1.ManagementModeR\x0emanagementMode\x12h\n\x15identity_provider_ref\x18\x04 \x01(\x0b\x32\x34.ai.stigmer.commons.apiresource.ApiResourceReferenceR\x13identityProviderRef\x12&\n\x0f\x65xternal_org_id\x18\x05 \x01(\tR\rexternalOrgId\x12\x1f\n\x0bis_personal\x18\x06 \x01(\x08R\nisPersonalB\xe0\x01\n&com.ai.stigmer.tenancy.organization.v1B\tSpecProtoP\x01\xa2\x02\x04\x41STO\xaa\x02\"Ai.Stigmer.Tenancy.Organization.V1\xca\x02\"Ai\\Stigmer\\Tenancy\\Organization\\V1\xe2\x02.Ai\\Stigmer\\Tenancy\\Organization\\V1\\GPBMetadata\xea\x02&Ai::Stigmer::Tenancy::Organization::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.tenancy.organization.v1.spec_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&com.ai.stigmer.tenancy.organization.v1B\tSpecProtoP\001\242\002\004ASTO\252\002\"Ai.Stigmer.Tenancy.Organization.V1\312\002\"Ai\\Stigmer\\Tenancy\\Organization\\V1\342\002.Ai\\Stigmer\\Tenancy\\Organization\\V1\\GPBMetadata\352\002&Ai::Stigmer::Tenancy::Organization::V1'
  _globals['_ORGANIZATIONSPEC'].fields_by_name['description']._loaded_options = None
  _globals['_ORGANIZATIONSPEC'].fields_by_name['description']._serialized_options = b'\272H\005r\003\030\364\003'
  _globals['_ORGANIZATIONSPEC'].fields_by_name['logo_url']._loaded_options = None
  _globals['_ORGANIZATIONSPEC'].fields_by_name['logo_url']._serialized_options = b'\272H\005r\003\030\200\020'
  _globals['_ORGANIZATIONSPEC']._serialized_start=203
  _globals['_ORGANIZATIONSPEC']._serialized_end=574
# @@protoc_insertion_point(module_scope)
